@@ -181,7 +181,7 @@ pub trait CSharpWriter {
             let the_type = self.converter().function_parameter_to_csharp_typename(p, function);
 
             match p.the_type() {
-                CType::Pattern(TypePattern::Slice(_)) => {
+                CType::Pattern(TypePattern::Slice(_) | TypePattern::SliceMut(_)) => {
                     to_pin_name.push(name);
                     to_pin_slice_type.push(the_type);
                     to_invoke.push(format!("{}_slice", name));
@@ -295,13 +295,40 @@ pub trait CSharpWriter {
                         w.newline()?;
                     }
                 }
-                TypePattern::Bool => {}
+                TypePattern::Bool => {
+                    // Bool is an item that can only be written once and uses `config.common_items_in_namespace_id`
+                    // to determine where it should go.
+                    if self.should_emit(&Meta::with_namespace_documentation(
+                        self.config().common_items_in_namespace_id.to_string(),
+                        Documentation::new(),
+                    )) {
+                        self.write_type_definition_ffibool(w)?;
+                        w.newline()?;
+                    }
+                }
+
                 TypePattern::APIVersion => {}
             },
         }
         Ok(())
     }
 
+    fn write_type_definition_ffibool(&self, w: &mut IndentWriter) -> Result<(), Error> {
+        self.debug(w, "write_type_definition_ffibool")?;
+
+        indented!(w, r#"[Serializable]"#)?;
+        indented!(w, r#"[StructLayout(LayoutKind.Sequential)]"#)?;
+        indented!(w, r#"public partial struct FFIBool"#)?;
+        indented!(w, r#"{{"#)?;
+        indented!(w, [_], r#"public static readonly FFIBool True = new FFIBool {{ value =  1 }};"#)?;
+        indented!(w, [_], r#"public static readonly FFIBool False = new FFIBool {{ value =  0 }};"#)?;
+        indented!(w, [_], r#"byte value;"#)?;
+        indented!(w, [_], r#"public bool Is => value == 1;"#)?;
+        indented!(w, r#"}}"#)?;
+        w.newline()?;
+        Ok(())
+    }
+
     fn write_type_definition_fn_pointer(&self, w: &mut IndentWriter, the_type: &FnPointerType) -> Result<(), Error> {
         self.debug(w, "write_type_definition_fn_pointer")?;
         self.write_type_definition_fn_pointer_annotation(w, the_type)?;
